Getting Started — Renku 0.15.2.dev42-g8ea0d1bb-dirty documentation

# Getting Started

Interaction with the platform can take place via the command-line interface (CLI).

Start by creating for folder where you want to keep your Renku project:

    $ renku init my-renku-project
    $ cd my-renku-project

Create a dataset and add data to it:

    $ renku dataset create my-dataset
    $ renku dataset add my-dataset https://raw.githubusercontent.com/SwissDataScienceCenter/renku-python/master/README.rst

Run an analysis:

    $ renku run wc < data/my-dataset/README.rst > wc_readme

Trace the data provenance:

    $ renku log wc_readme

These are the basics, but there is much more that Renku allows you to do with your data analysis workflows.

For more information about using renku, refer to the renku –help.